@@ -1,4 +1,4 @@
 library(drfit)
 data(IM1xIPC81)
 rIM1xIPC81 <- drfit(IM1xIPC81,linlogit=TRUE)
-rIM1xIPC81
+print(rIM1xIPC81,digits=5)
